@@ -14,7 +14,7 @@ if(is.null(group)) {answer <- describe(x,type=type)
    warning("no grouping variable requested")} else {
    if(!is.data.frame(group) && !is.list(group) && (length(group) < NROW(x))) group <- x[,group]
 		answer <- by(x,group,describe,type=type,...)
-      	 #class(answer) <- c("psych","describe")  #probably better not to make of class psych (at least not yet)
+      	 class(answer) <- c("psych","describeBy")  #probably better not to make of class psych (at least not yet)
        	}
 
 if (mat) { ncol <- length(answer[[1]])  #the more complicated case. How to reorder a list of data.frames
