@@ -11,7 +11,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,s
    cl <- match.call()
    n <- dim(r)[2]
   
-   if (n!=dim(r)[1]) {
+   if (!isCorrelation(r)) {
                     raw <- TRUE
       				n.obs <- dim(r)[1] 
       				if(scores) {x.matrix <- as.matrix(r)  #matrices are required for the substitution to work
